==> forms-v5.2.1.tar.gz: forms/l10n/ast.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "{user} has shared the form {formTitle} with you" : "{user} compartió'l formulariu «{formTitle}» contigo",
    "{user} has shared the form {formTitle} with group {group}" : "{user} compartió'l formulariu «{formTitle}» col grupu «{group}»",
    "{user} has shared the form {formTitle} with team {circle}" : "{user} compartió'l formulariu «{formTitle}» col equipu «{circle}»",
    "Anonymous user" : "Usuariu anónimu",
    "A form has been <strong>shared</strong> with you" : "<strong>Compartióse</strong> un formulariu contigo",
    "No" : "Non",
    "Yes" : "Sí",
    "Question" : "Entruga",
    "Copy" : "Copiar",
    "Anonymous response" : "Rempuesta anónima",
    "responses" : "rempuestes",
    "Timestamp" : "Marca de tiempu",
    "An error occurred while loading the forms list" : "Prodúxose un error mentanto se cargaba la llista de formularios",
    "Form not found" : "Nun s'atopó'l formulariu",
    "Unable to create a new form" : "Nun ye posible crear un formulariu",
    "Unable to copy form" : "Nun ye posible copiar el formulariu",
    "New form" : "Formulariu nuevu",
    "Shared with you" : "Compartióse contigo",
    "Archived forms" : "Formularios archivaos",
    "Loading forms …" : "Cargando los formularios…",
    "No forms created yet" : "Nun se creó nengún formulariu",
    "Please select a form" : "Seleiciona un formulariu",
    "Create new form" : "Crear un formulariu",
    "This form does not exist" : "Esti formulariu nun esiste",
    "Form expired" : "El formulariu caducó",
    "Error while saving configuration" : "Hebo un error mentanto se guardaba la configuración",
    "Error while reloading config" : "Hebo un error mentanto se volvia guardar la configuración",
    "Select groups" : "Seleicionar grupos",
    "Form actions" : "Aiciones del formulariu",
    "Edit form" : "Editar el formulariu",
    "Results" : "Resultaos",
    "Cancel" : "Encaboxar",
    "Options" : "Opciones",
    "Go to previous page" : "Dir a la páxina anterior",
    "This question needs a title!" : "¡Esta entruga precisa un títulu!",
    "Technical name" : "Nome téunicu",
    "Copy question" : "Copiar la entruga",
    "Delete question" : "Desaniciar la entruga",
    "Delete" : "Desaniciar",
    "Uploading …" : "Xubiendo…",
    "Invalid regular expression" : "La espresión regular ye inválida",
    "No response" : "Nun hai nenguna rempuesta",
    "Delete this response" : "Desaniciar esta rempuesta",
    "never" : "enxamás",
    "Store responses anonymously" : "Atroxar anónimamente les rempuestes",
    "Set expiration date" : "Afitar la data de caducidá",
    "Show expiration date on form" : "Amosar la data de caducidá nel formulariu",
    "Group" : "Grupu",
    "Team" : "Equipu",
    "Permissions" : "Permisos",
    "View responses" : "Ver les rempuestes",
    "Delete responses" : "Desaniciar les rempuestes",
    "There was an error while adding the share" : "Hebo un error mentanto s'amestaba l'elementu compartíu",
    "There was an error while adding the link" : "Hebo un error mentanto s'amestaba l'enllaz",
    "There was an error while updating the share" : "Hebo un error mentanto s'anovaba l'elementu compartíu",
    "There was an error while removing the share" : "Hebo un error mentanto se quitaba l'elementu compartíu",
    "Share link" : "Compartir l'enllaz",
    "Add link" : "Amestar un enllaz",
    "Embeddable link" : "Enllaz empotrable",
    "Copy to clipboard" : "Copiar nel cartafueyu",
    "Show QR code" : "Amosar el códigu QR",
    "Copy embedding code" : "Copiar el códigu empotráu",
    "Remove link" : "Quitar l'enllaz",
    "Internal link" : "Enllaz internu",
    "An error occurred while transfering ownership" : "Prodúxose un error mentanto se tresfería la propiedá",
    "Transfer ownership" : "Tresferir la propiedá",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Vas tresferir la propiedá de «{name}» a otra cuenta. Seleiciona la cuenta a la que quies tresferir la propiedá.",
    "Confirmation text" : "Testu de confirmación",
    "This can not be undone." : "Esta aición nun se pue desfacer.",
    "View" : "Ver",
    "Edit" : "Editar",
    "Show results" : "Amosar los resultaos",
    "Share" : "Compartir",
    "Responses are anonymous." : "Les rempuestes son anónimes.",
    "There was an error while adding the new question" : "Hebo un error mentanto s'amestaba la entruga nueva",
    "There was an error while removing the question" : "Hebo un error mentanto se quitaba la entruga",
    "Error while saving form" : "Hebo un error mentanto se guardaba'l formulariu",
    "Loading {title} …" : "Cargando «{title}»…",
    "Form is archived" : "El formulariu ta archiváu",
    "Description" : "Descripción",
    "Summary" : "Resume",
    "Responses" : "Rempuestes",
    "Unlink spreadsheet" : "Desenllaciar la fueya de cálculu",
    "Create spreadsheet" : "Crear la fueya de cálculu",
    "Delete submissions" : "Desaniciar los unvios",
    "There was an error while loading the results" : "Hebo un error mentanto se guardaben los resultaos",
    "There was an error while linking the file" : "Hebo un error mentanto d'enllaciaba'l ficheru",
    "There was an error while exporting to Files" : "Hebo error mentanto s'esportaba a Ficheros",
    "File is not linked" : "El ficheru ta enllaciáu",
    "There was an error, while exporting to Files" : "Hebo un error mentanto s'esportaba a Ficheros",
    "Submission deleted" : "Desaniciáronse los unvios",
    "There was an error while removing this response" : "Hebo un error mentanto se quitaba esta rempuesta",
    "There was an error while removing responses" : "Hebo un error mentanto se quitaben les rempuestes",
    "Linked file not available" : "El ficheru enllaciáu nun ta disponible",
    "Linked file is not available, would you like to link a new file?" : "El ficheru enllaciáu nun ta disponible, ¿quies enllaciar otru nuevu?",
    "{amount} responses" : "{amount} rempuestes",
    "Open spreadsheet" : "Abrir la fueya de cálculu",
    "Re-export spreadsheet" : "Volver esportar la fueya de cálculu",
    "Save copy to Files" : "Guardar la copia en Ficheros",
    "Download" : "Baxar",
    "Delete all responses" : "Desaniciar toles rempuestes",
    "Search" : "Buscar",
    "Loading responses …" : "Cargando les rempuesta…",
    "No results found" : "Nun s'atopó nengún resultáu",
    "No responses yet" : "Nun hai nenguna rempuesta",
    "Results of submitted forms will show up here" : "Equí apaecen los resultaos de los formularios unviaos",
    "Are you sure you want to delete all responses of {title}?" : "¿De xuru que quies desaniciar toles rempuestes de «{title}»?",
    "Form settings" : "Configuración del formulariu",
    "Sharing" : "Comparticiñon",
    "Settings" : "Configuración",
    "Abort" : "Albortar",
    "Submit" : "Unviar",
    "Leave" : "Colar",
    "Clear" : "Borrar",
    "There was an error submitting the form" : "Hebo un error al unviar el formulariu",
    "Submit form" : "Unviar el formulariu",
    "Submitting form …" : "Unviando'l formulariu…",
    "Thank you for completing the form!" : "¡Gracies por completar el formulariu!",
    "Confirm submit" : "Confirmar el formulariu",
    "Are you sure you want to submit an empty form?" : "¿De xuru que quies unviar un formulariu baleru?",
    "Leave form" : "Colar del formulariu",
    "You have unsaved changes! Do you still want to leave?" : "¡Tienes cambeos ensin guardar! ¿Quies colar de toes toes?",
    "Error while saving question" : "Hebo un error mentanto guardaba la entruga",
    "There was an issue deleting this option" : "Hebo un problema al desaniciar esta opción",
    "Form link copied" : "Copióse l'enllaz del formulariu",
    "Cannot copy, please copy the link manually" : "Nun se pue copiar. Copia l'enllaz manualmente",
    "No recommendations. Start typing." : "Nun hai nenguna recomendación. Comienza a escribir",
    "No elements found." : "Nun s'atopó nengún elementu.",
    "Checkboxes" : "Caxellos",
    "People can submit a different answer" : "La xente pue unviar otres rempuestes",
    "Enter your answer" : "Introduz una rempuesta",
    "This question needs a title and at least one answer!" : "¡Esta entruga precisa polo menos un títulu y una rempuesta!",
    "People can pick one option" : "La xente pue escoyer una opción",
    "Pick an option" : "Escueyi una opción",
    "File" : "Ficheru",
    "Short answer" : "Rempuesta curtia",
    "People can enter a short answer" : "La xente pue introducir rempuestes curties",
    "Date" : "Data",
    "Pick a date" : "Escueyi una data",
    "Time" : "Data",
    "Color" : "Color",
    "Image" : "Imaxe",
    "Document" : "Documentu",
    "Presentation" : "Presentación",
    "Spreadsheet" : "Fueya de cálculu",
    "Text" : "Testu",
    "Phone number" : "Númberu de teléfonu",
    "People can enter a telephone number" : "La xente pue introducir un númberu de teléfonu",
    "Email address" : "Direición de corréu electrónicu",
    "People can enter an email address" : "La xente pue introducir una direición de corréu electrónicu",
    "Number" : "Númberu",
    "People can enter a number" : "La xente pue introducir un númberu"
},
"nplurals=2; plural=(n != 1);");

==> forms-v5.2.3.tar.gz: forms/l10n/ast.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "{user} has shared the form {formTitle} with you" : "{user} compartió'l formulariu «{formTitle}» contigo",
    "{user} has shared the form {formTitle} with group {group}" : "{user} compartió'l formulariu «{formTitle}» col grupu «{group}»",
    "{user} has shared the form {formTitle} with team {circle}" : "{user} compartió'l formulariu «{formTitle}» col equipu «{circle}»",
    "Anonymous user" : "Usuariu anónimu",
    "A form has been <strong>shared</strong> with you" : "<strong>Compartióse</strong> un formulariu contigo",
    "No" : "Non",
    "Yes" : "Sí",
    "Question" : "Entruga",
    "Copy" : "Copiar",
    "Anonymous response" : "Rempuesta anónima",
    "responses" : "rempuestes",
    "Timestamp" : "Marca de tiempu",
    "An error occurred while loading the forms list" : "Prodúxose un error mentanto se cargaba la llista de formularios",
    "Form not found" : "Nun s'atopó'l formulariu",
    "Unable to create a new form" : "Nun ye posible crear un formulariu",
    "Unable to copy form" : "Nun ye posible copiar el formulariu",
    "New form" : "Formulariu nuevu",
    "Shared with you" : "Compartióse contigo",
    "Archived forms" : "Formularios archivaos",
    "No forms created yet" : "Nun se creó nengún formulariu",
    "Please select a form" : "Seleiciona un formulariu",
    "Create new form" : "Crear un formulariu",
    "This form does not exist" : "Esti formulariu nun esiste",
    "Form expired" : "El formulariu caducó",
    "Error while saving configuration" : "Hebo un error mentanto se guardaba la configuración",
    "Error while reloading config" : "Hebo un error mentanto se volvia guardar la configuración",
    "Select groups" : "Seleicionar grupos",
    "Form actions" : "Aiciones del formulariu",
    "Edit form" : "Editar el formulariu",
    "Results" : "Resultaos",
    "Cancel" : "Encaboxar",
    "Options" : "Opciones",
    "Go to previous page" : "Dir a la páxina anterior",
    "This question needs a title!" : "¡Esta entruga precisa un títulu!",
    "Technical name" : "Nome téunicu",
    "Copy question" : "Copiar la entruga",
    "Delete question" : "Desaniciar la entruga",
    "Delete" : "Desaniciar",
    "Invalid regular expression" : "La espresión regular ye inválida",
    "No response" : "Nun hai nenguna rempuesta",
    "Delete this response" : "Desaniciar esta rempuesta",
    "never" : "enxamás",
    "Store responses anonymously" : "Atroxar anónimamente les rempuestes",
    "Set expiration date" : "Afitar la data de caducidá",
    "Show expiration date on form" : "Amosar la data de caducidá nel formulariu",
    "Group" : "Grupu",
    "Team" : "Equipu",
    "Permissions" : "Permisos",
    "View responses" : "Ver les rempuestes",
    "Delete responses" : "Desaniciar les rempuestes",
    "There was an error while adding the share" : "Hebo un error mentanto s'amestaba l'elementu compartíu",
    "There was an error while adding the link" : "Hebo un error mentanto s'amestaba l'enllaz",
    "There was an error while updating the share" : "Hebo un error mentanto s'anovaba l'elementu compartíu",
    "There was an error while removing the share" : "Hebo un error mentanto se quitaba l'elementu compartíu",
    "Share link" : "Compartir l'enllaz",
    "Add link" : "Amestar un enllaz",
    "Embeddable link" : "Enllaz empotrable",
    "Copy to clipboard" : "Copiar nel cartafueyu",
    "Show QR code" : "Amosar el códigu QR",
    "Copy embedding code" : "Copiar el códigu empotráu",
    "Remove link" : "Quitar l'enllaz",
    "Internal link" : "Enllaz internu",
    "An error occurred while transfering ownership" : "Prodúxose un error mentanto se tresfería la propiedá",
    "Transfer ownership" : "Tresferir la propiedá",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Vas tresferir la propiedá de «{name}» a otra cuenta. Seleiciona la cuenta a la que quies tresferir la propiedá.",
    "Confirmation text" : "Testu de confirmación",
    "This can not be undone." : "Esta aición nun se pue desfacer.",
    "View" : "Ver",
    "Edit" : "Editar",
    "Show results" : "Amosar los resultaos",
    "Share" : "Compartir",
    "Responses are anonymous." : "Les rempuestes son anónimes.",
    "There was an error while adding the new question" : "Hebo un error mentanto s'amestaba la entruga nueva",
    "There was an error while removing the question" : "Hebo un error mentanto se quitaba la entruga",
    "Error while saving form" : "Hebo un error mentanto se guardaba'l formulariu",
    "Form is archived" : "El formulariu ta archiváu",
    "Description" : "Descripción",
    "Summary" : "Resume",
    "Responses" : "Rempuestes",
    "Unlink spreadsheet" : "Desenllaciar la fueya de cálculu",
    "Create spreadsheet" : "Crear la fueya de cálculu",
    "Delete submissions" : "Desaniciar los unvios",
    "There was an error while loading the results" : "Hebo un error mentanto se guardaben los resultaos",
    "There was an error while linking the file" : "Hebo un error mentanto d'enllaciaba'l ficheru",
    "There was an error while exporting to Files" : "Hebo error mentanto s'esportaba a Ficheros",
    "File is not linked" : "El ficheru ta enllaciáu",
    "There was an error, while exporting to Files" : "Hebo un error mentanto s'esportaba a Ficheros",
    "Submission deleted" : "Desaniciáronse los unvios",
    "There was an error while removing this response" : "Hebo un error mentanto se quitaba esta rempuesta",
    "There was an error while removing responses" : "Hebo un error mentanto se quitaben les rempuestes",
    "Linked file not available" : "El ficheru enllaciáu nun ta disponible",
    "Linked file is not available, would you like to link a new file?" : "El ficheru enllaciáu nun ta disponible, ¿quies enllaciar otru nuevu?",
    "{amount} responses" : "{amount} rempuestes",
    "Open spreadsheet" : "Abrir la fueya de cálculu",
    "Re-export spreadsheet" : "Volver esportar la fueya de cálculu",
    "Save copy to Files" : "Guardar la copia en Ficheros",
    "Download" : "Baxar",
    "Delete all responses" : "Desaniciar toles rempuestes",
    "Search" : "Buscar",
    "No results found" : "Nun s'atopó nengún resultáu",
    "No responses yet" : "Nun hai nenguna rempuesta",
    "Results of submitted forms will show up here" : "Equí apaecen los resultaos de los formularios unviaos",
    "Are you sure you want to delete all responses of {title}?" : "¿De xuru que quies desaniciar toles rempuestes de «{title}»?",
    "Form settings" : "Configuración del formulariu",
    "Sharing" : "Comparticiñon",
    "Settings" : "Configuración",
    "Abort" : "Albortar",
    "Submit" : "Unviar",
    "Leave" : "Colar",
    "Clear" : "Borrar",
    "There was an error submitting the form" : "Hebo un error al unviar el formulariu",
    "Submit form" : "Unviar el formulariu",
    "Thank you for completing the form!" : "¡Gracies por completar el formulariu!",
    "Confirm submit" : "Confirmar el formulariu",
    "Are you sure you want to submit an empty form?" : "¿De xuru que quies unviar un formulariu baleru?",
    "Leave form" : "Colar del formulariu",
    "You have unsaved changes! Do you still want to leave?" : "¡Tienes cambeos ensin guardar! ¿Quies colar de toes toes?",
    "Error while saving question" : "Hebo un error mentanto guardaba la entruga",
    "There was an issue deleting this option" : "Hebo un problema al desaniciar esta opción",
    "Form link copied" : "Copióse l'enllaz del formulariu",
    "Cannot copy, please copy the link manually" : "Nun se pue copiar. Copia l'enllaz manualmente",
    "No recommendations. Start typing." : "Nun hai nenguna recomendación. Comienza a escribir",
    "No elements found." : "Nun s'atopó nengún elementu.",
    "Checkboxes" : "Caxellos",
    "People can submit a different answer" : "La xente pue unviar otres rempuestes",
    "Enter your answer" : "Introduz una rempuesta",
    "This question needs a title and at least one answer!" : "¡Esta entruga precisa polo menos un títulu y una rempuesta!",
    "People can pick one option" : "La xente pue escoyer una opción",
    "Pick an option" : "Escueyi una opción",
    "File" : "Ficheru",
    "Short answer" : "Rempuesta curtia",
    "People can enter a short answer" : "La xente pue introducir rempuestes curties",
    "Date" : "Data",
    "Pick a date" : "Escueyi una data",
    "Time" : "Data",
    "Color" : "Color",
    "Image" : "Imaxe",
    "Document" : "Documentu",
    "Presentation" : "Presentación",
    "Spreadsheet" : "Fueya de cálculu",
    "Text" : "Testu",
    "Phone number" : "Númberu de teléfonu",
    "People can enter a telephone number" : "La xente pue introducir un númberu de teléfonu",
    "Email address" : "Direición de corréu electrónicu",
    "People can enter an email address" : "La xente pue introducir una direición de corréu electrónicu",
    "Number" : "Númberu",
    "People can enter a number" : "La xente pue introducir un númberu",
    "Loading forms …" : "Cargando los formularios…",
    "Uploading …" : "Xubiendo…",
    "Loading {title} …" : "Cargando «{title}»…",
    "Loading responses …" : "Cargando les rempuesta…",
    "Submitting form …" : "Unviando'l formulariu…"
},
"nplurals=2; plural=(n != 1);");
